import os.path
parent = (os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))


def style(name='default'):
    style = {'default' : 'bd=0;bg=#ffffff;',
             'default2' : 'bd=0;bg=#7d7d7d;',
             'default4' : 'path='+parent+'/img/rv.png;',
             'default5' : 'path='+parent+'/img/wv.png;',
             'default6' : 'path='+parent+'/img/bb.png;',
             'Bfc' : 'bg=#f7f7f7;bd=0;',
             'lkst' : 'path='+parent+'/img/linkstat.png;circular=True;',
             'lksh' : 'path='+parent+'/img/linksearch.png;circular=True;',
             'lksv' : 'path='+parent+'/img/linksave.png;circular=True;',
             'lked' : 'path='+parent+'/img/linked.png;circular=True;',
             'lkedyn' : 'path='+parent+'/img/linkdyn.png;circular=True;',
             'lkdl' : 'path='+parent+'/img/linkdel.png;circular=True;',
             'kwsv' : 'path='+parent+'/img/kwsv.png;circular=True;',
             'pin' : 'path='+parent+'/img/pin.png;circular=True;',
             'domains' : 'path='+parent+'/img/domains.png;circular=True;',
             'keywords' : 'path='+parent+'/img/keywords.png;circular=True;',
             'history' : 'path='+parent+'/img/history.png;circular=True;',
             'media' : 'path='+parent+'/img/media.png;circular=True;',
             'folders' : 'path='+parent+'/img/folders.png;circular=True;',
             'Tbd' : 'bd=0;bg=#ffffff;fg=#0000cd;highlightthickness=2;highlightcolor=#0000cd;',
             'folder' : 'path='+parent+'/img/folder.jpg;',
             'Xbg' : 'path='+parent+'/img/xbg.png;',
             'Wbg' : 'bd=0;bg=#ffffff;',
             'Bbg' : 'bd=0;bg=#0000cd;',
             'butCnv' : 'image=;width=7;height=2;fg=#7d7d7d;',
             'navClick' : 'bg=#0000cd;highlightcolor=#0000cd;',
             'DlogoR' : 'path='+parent+'/img/logo.png;',
             'DlogoR2' : 'path='+parent+'/img/logo2.png;',
             'Dtext' : 'text=Dosie;font=Helvetica 11 bold;image=;width=5;height=2;',
             'blueBr' : 'path='+parent+'/img/blueButton.png;',
             'nBott' : 'path='+parent+'/img/bh.png;',
             'topIndL' : 'path='+parent+'/img/lt.png;',
             'topIndLT' : 'image=;width=30;height=2;text=Start new search;anchor=w;fg=#7d7d7d;',
             'google' : 'path='+parent+'/img/google.png;circular=True;',
             'Dbg' : 'bd=0;bg=#f0f0f0;padx=1;pady=1;',
             'bgb' : 'background=#0000cd;rad=58;',
             'bgw' : 'background=#ffffff;rad=58;',
             'ctB' : 'bg=#000080;',
             'ctrlCnrOP' : 'path='+parent+'/img/cop.png;',
             'settings1' : 'path='+parent+'/img/set1.png;circular=True;',
             'settings2' : 'path='+parent+'/img/set2.png;circular=True;',
             'settings3' : 'path='+parent+'/img/set3.png;circular=True;',
             'relev' : 'path='+parent+'/img/pers.png;',
             'load' : 'path='+parent+'/img/load.png;circular=True;',
             'fim' : 'path='+parent+'/img/domainICO/Icon.png;circular=True;',
             'pdf' : 'path='+parent+'/img/pdf.png;',
             'mp4' : 'path='+parent+'/img/mp4.png;',
             'jpg' : 'path='+parent+'/img/jpg.png;',
             'png' : 'path='+parent+'/img/png.png;',
             'mp3' : 'path='+parent+'/img/mp3.png;',
             'wav' : 'path='+parent+'/img/wav.png;',
             'txt' : 'path='+parent+'/img/txt.png;',
             }
    
    return style[name]
